/*
 * Copyright 2010-2023 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.comprehend.model.transform;

import com.amazonaws.services.comprehend.model.*;
import com.amazonaws.util.DateUtils;
import com.amazonaws.util.json.AwsJsonWriter;

/**
 * JSON marshaller for POJO DatasetAugmentedManifestsListItem
 */
class DatasetAugmentedManifestsListItemJsonMarshaller {

    public void marshall(DatasetAugmentedManifestsListItem datasetAugmentedManifestsListItem,
            AwsJsonWriter jsonWriter) throws Exception {
        jsonWriter.beginObject();
        if (datasetAugmentedManifestsListItem.getAttributeNames() != null) {
            java.util.List<String> attributeNames = datasetAugmentedManifestsListItem
                    .getAttributeNames();
            jsonWriter.name("AttributeNames");
            jsonWriter.beginArray();
            for (String attributeNamesItem : attributeNames) {
                if (attributeNamesItem != null) {
                    jsonWriter.value(attributeNamesItem);
                }
            }
            jsonWriter.endArray();
        }
        if (datasetAugmentedManifestsListItem.getS3Uri() != null) {
            String s3Uri = datasetAugmentedManifestsListItem.getS3Uri();
            jsonWriter.name("S3Uri");
            jsonWriter.value(s3Uri);
        }
        if (datasetAugmentedManifestsListItem.getAnnotationDataS3Uri() != null) {
            String annotationDataS3Uri = datasetAugmentedManifestsListItem.getAnnotationDataS3Uri();
            jsonWriter.name("AnnotationDataS3Uri");
            jsonWriter.value(annotationDataS3Uri);
        }
        if (datasetAugmentedManifestsListItem.getSourceDocumentsS3Uri() != null) {
            String sourceDocumentsS3Uri = datasetAugmentedManifestsListItem
                    .getSourceDocumentsS3Uri();
            jsonWriter.name("SourceDocumentsS3Uri");
            jsonWriter.value(sourceDocumentsS3Uri);
        }
        if (datasetAugmentedManifestsListItem.getDocumentType() != null) {
            String documentType = datasetAugmentedManifestsListItem.getDocumentType();
            jsonWriter.name("DocumentType");
            jsonWriter.value(documentType);
        }
        jsonWriter.endObject();
    }

    private static DatasetAugmentedManifestsListItemJsonMarshaller instance;

    public static DatasetAugmentedManifestsListItemJsonMarshaller getInstance() {
        if (instance == null)
            instance = new DatasetAugmentedManifestsListItemJsonMarshaller();
        return instance;
    }
}
