/*
 * Copyright 2010-2023 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.comprehend.model.transform;

import com.amazonaws.services.comprehend.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for POJO DocumentClassifierInputDataConfig
 */
class DocumentClassifierInputDataConfigJsonUnmarshaller implements
        Unmarshaller<DocumentClassifierInputDataConfig, JsonUnmarshallerContext> {

    public DocumentClassifierInputDataConfig unmarshall(JsonUnmarshallerContext context)
            throws Exception {
        AwsJsonReader reader = context.getReader();
        if (!reader.isContainer()) {
            reader.skipValue();
            return null;
        }
        DocumentClassifierInputDataConfig documentClassifierInputDataConfig = new DocumentClassifierInputDataConfig();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("DataFormat")) {
                documentClassifierInputDataConfig.setDataFormat(StringJsonUnmarshaller
                        .getInstance()
                        .unmarshall(context));
            } else if (name.equals("S3Uri")) {
                documentClassifierInputDataConfig.setS3Uri(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("TestS3Uri")) {
                documentClassifierInputDataConfig.setTestS3Uri(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("LabelDelimiter")) {
                documentClassifierInputDataConfig.setLabelDelimiter(StringJsonUnmarshaller
                        .getInstance()
                        .unmarshall(context));
            } else if (name.equals("AugmentedManifests")) {
                documentClassifierInputDataConfig
                        .setAugmentedManifests(new ListUnmarshaller<AugmentedManifestsListItem>(
                                AugmentedManifestsListItemJsonUnmarshaller.getInstance()
                        )
                                .unmarshall(context));
            } else if (name.equals("DocumentType")) {
                documentClassifierInputDataConfig.setDocumentType(StringJsonUnmarshaller
                        .getInstance()
                        .unmarshall(context));
            } else if (name.equals("Documents")) {
                documentClassifierInputDataConfig
                        .setDocuments(DocumentClassifierDocumentsJsonUnmarshaller.getInstance()
                                .unmarshall(context));
            } else if (name.equals("DocumentReaderConfig")) {
                documentClassifierInputDataConfig
                        .setDocumentReaderConfig(DocumentReaderConfigJsonUnmarshaller.getInstance()
                                .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();
        return documentClassifierInputDataConfig;
    }

    private static DocumentClassifierInputDataConfigJsonUnmarshaller instance;

    public static DocumentClassifierInputDataConfigJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new DocumentClassifierInputDataConfigJsonUnmarshaller();
        return instance;
    }
}
