/*
 * Copyright 2010-2023 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.comprehend.model.transform;

import com.amazonaws.services.comprehend.model.*;
import com.amazonaws.util.DateUtils;
import com.amazonaws.util.json.AwsJsonWriter;

/**
 * JSON marshaller for POJO Entity
 */
class EntityJsonMarshaller {

    public void marshall(Entity entity, AwsJsonWriter jsonWriter) throws Exception {
        jsonWriter.beginObject();
        if (entity.getScore() != null) {
            Float score = entity.getScore();
            jsonWriter.name("Score");
            jsonWriter.value(score);
        }
        if (entity.getType() != null) {
            String type = entity.getType();
            jsonWriter.name("Type");
            jsonWriter.value(type);
        }
        if (entity.getText() != null) {
            String text = entity.getText();
            jsonWriter.name("Text");
            jsonWriter.value(text);
        }
        if (entity.getBeginOffset() != null) {
            Integer beginOffset = entity.getBeginOffset();
            jsonWriter.name("BeginOffset");
            jsonWriter.value(beginOffset);
        }
        if (entity.getEndOffset() != null) {
            Integer endOffset = entity.getEndOffset();
            jsonWriter.name("EndOffset");
            jsonWriter.value(endOffset);
        }
        if (entity.getBlockReferences() != null) {
            java.util.List<BlockReference> blockReferences = entity.getBlockReferences();
            jsonWriter.name("BlockReferences");
            jsonWriter.beginArray();
            for (BlockReference blockReferencesItem : blockReferences) {
                if (blockReferencesItem != null) {
                    BlockReferenceJsonMarshaller.getInstance().marshall(blockReferencesItem,
                            jsonWriter);
                }
            }
            jsonWriter.endArray();
        }
        jsonWriter.endObject();
    }

    private static EntityJsonMarshaller instance;

    public static EntityJsonMarshaller getInstance() {
        if (instance == null)
            instance = new EntityJsonMarshaller();
        return instance;
    }
}
