/*
 * Copyright 2010-2021 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.lexrts.model.transform;

import com.amazonaws.services.lexrts.model.*;
import com.amazonaws.transform.SimpleTypeJsonUnmarshallers.*;
import com.amazonaws.transform.*;
import com.amazonaws.util.json.AwsJsonReader;

/**
 * JSON unmarshaller for POJO IntentSummary
 */
class IntentSummaryJsonUnmarshaller implements Unmarshaller<IntentSummary, JsonUnmarshallerContext> {

    public IntentSummary unmarshall(JsonUnmarshallerContext context) throws Exception {
        AwsJsonReader reader = context.getReader();
        if (!reader.isContainer()) {
            reader.skipValue();
            return null;
        }
        IntentSummary intentSummary = new IntentSummary();
        reader.beginObject();
        while (reader.hasNext()) {
            String name = reader.nextName();
            if (name.equals("intentName")) {
                intentSummary.setIntentName(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("checkpointLabel")) {
                intentSummary.setCheckpointLabel(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("slots")) {
                intentSummary.setSlots(new MapUnmarshaller<String>(StringJsonUnmarshaller
                        .getInstance()
                        )
                                .unmarshall(context));
            } else if (name.equals("confirmationStatus")) {
                intentSummary.setConfirmationStatus(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("dialogActionType")) {
                intentSummary.setDialogActionType(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("fulfillmentState")) {
                intentSummary.setFulfillmentState(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else if (name.equals("slotToElicit")) {
                intentSummary.setSlotToElicit(StringJsonUnmarshaller.getInstance()
                        .unmarshall(context));
            } else {
                reader.skipValue();
            }
        }
        reader.endObject();
        return intentSummary;
    }

    private static IntentSummaryJsonUnmarshaller instance;

    public static IntentSummaryJsonUnmarshaller getInstance() {
        if (instance == null)
            instance = new IntentSummaryJsonUnmarshaller();
        return instance;
    }
}
