/*
 * Copyright 2010-2023 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.rekognition.model;

import java.util.HashMap;
import java.util.Map;

/**
 * Attribute
 */
public enum Attribute {

    DEFAULT("DEFAULT"),
    ALL("ALL"),
    AGE_RANGE("AGE_RANGE"),
    BEARD("BEARD"),
    EMOTIONS("EMOTIONS"),
    EYE_DIRECTION("EYE_DIRECTION"),
    EYEGLASSES("EYEGLASSES"),
    EYES_OPEN("EYES_OPEN"),
    GENDER("GENDER"),
    MOUTH_OPEN("MOUTH_OPEN"),
    MUSTACHE("MUSTACHE"),
    FACE_OCCLUDED("FACE_OCCLUDED"),
    SMILE("SMILE"),
    SUNGLASSES("SUNGLASSES");

    private String value;

    private Attribute(String value) {
        this.value = value;
    }

    @Override
    public String toString() {
        return value;
    }

    private static final Map<String, Attribute> enumMap;
    static {
        enumMap = new HashMap<String, Attribute>();
        enumMap.put("DEFAULT", DEFAULT);
        enumMap.put("ALL", ALL);
        enumMap.put("AGE_RANGE", AGE_RANGE);
        enumMap.put("BEARD", BEARD);
        enumMap.put("EMOTIONS", EMOTIONS);
        enumMap.put("EYE_DIRECTION", EYE_DIRECTION);
        enumMap.put("EYEGLASSES", EYEGLASSES);
        enumMap.put("EYES_OPEN", EYES_OPEN);
        enumMap.put("GENDER", GENDER);
        enumMap.put("MOUTH_OPEN", MOUTH_OPEN);
        enumMap.put("MUSTACHE", MUSTACHE);
        enumMap.put("FACE_OCCLUDED", FACE_OCCLUDED);
        enumMap.put("SMILE", SMILE);
        enumMap.put("SUNGLASSES", SUNGLASSES);
    }

    /**
     * Use this in place of valueOf.
     *
     * @param value real value
     * @return Attribute corresponding to the value
     */
    public static Attribute fromValue(String value) {
        if (value == null || value.isEmpty()) {
            throw new IllegalArgumentException("Value cannot be null or empty!");
        } else if (enumMap.containsKey(value)) {
            return enumMap.get(value);
        } else {
            throw new IllegalArgumentException("Cannot create enum from " + value + " value!");
        }
    }
}
