/*
 * Copyright 2010-2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */

package com.amazonaws.services.rekognition.model.transform;

import com.amazonaws.services.rekognition.model.*;
import com.amazonaws.util.json.AwsJsonWriter;

/**
 * JSON marshaller for POJO Section
 */
class SectionJsonMarshaller {

    public void marshall(Section section, AwsJsonWriter jsonWriter) throws Exception {
        jsonWriter.beginObject();
        if (section.getStartTimestamp() != null) {
            Long startTimestamp = section.getStartTimestamp();
            jsonWriter.name("StartTimestamp");
            jsonWriter.value(startTimestamp);
        }
        if (section.getEndTimestamp() != null) {
            Long endTimestamp = section.getEndTimestamp();
            jsonWriter.name("EndTimestamp");
            jsonWriter.value(endTimestamp);
        }
        jsonWriter.endObject();
    }

    private static SectionJsonMarshaller instance;

    public static SectionJsonMarshaller getInstance() {
        if (instance == null)
            instance = new SectionJsonMarshaller();
        return instance;
    }
}
